"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildTestCommand = void 0;
const commander_1 = require("commander");
const runTests_1 = __importDefault(require("./runTests"));
const buildTestCommand = () => {
    const command = new commander_1.Command("test")
        .description("🏃 Run QA Wolf tests, optionally specifying a list of test tag names")
        .option("-t, --tags <tags>", "comma separated list of tag names (example: Account,Checkout)")
        .option("-e, --environment <environment>", "environment name to use when running your tests (example: Staging)")
        .option("-v, --variables <variables>", "environment variables to pass to your tests")
        .option("--no-wait", "do not wait for the tests finish running")
        .option("-b, --branch <branch>", "git branch of tests to run")
        .option("--trigger <id>", "deprecated: id of the trigger to run")
        .action(async ({ branch, environment, tags, trigger: triggerId, variables, wait, }) => {
        await runTests_1.default({
            branch,
            environment,
            tags,
            triggerId,
            variables,
            wait,
        });
    });
    return command;
};
exports.buildTestCommand = buildTestCommand;
//# sourceMappingURL=testCommand.js.map